@@ -4,9 +4,8 @@ use pyo3::{
 };
 use pyo3_stub_gen::derive::*;
 use statsig_rust::{
-    event_logging::exposable_string::ExposableString, interned_string::InternedString, log_d,
-    log_e, log_w, PersistentStorage, SecondaryExposure, StickyValues as StickyValuesActual,
-    UserPersistedValues as UserPersistedValuesActual,
+    interned_string::InternedString, log_d, log_e, log_w, PersistentStorage, SecondaryExposure,
+    StickyValues as StickyValuesActual, UserPersistedValues as UserPersistedValuesActual,
 };
 use std::collections::HashMap;
 
@@ -64,7 +63,7 @@ pub fn convert_dict_to_user_persisted_values(
 
             let sticky_value = StickyValuesActual {
                 value,
-                rule_id: rule_id.map(|r| ExposableString::from_str_ref(r.as_str())),
+                rule_id: rule_id.map(InternedString::from_string),
                 group_name,
                 config_delegate,
                 time,
@@ -170,7 +169,7 @@ fn convert_py_dict_to_secondary_exposure(py_dict: &Bound<PyDict>) -> PyResult<Se
     Ok(SecondaryExposure {
         gate: InternedString::from_string(gate),
         gate_value: InternedString::from_string(gate_value),
-        rule_id: ExposableString::from_str_ref(rule_id.as_str()),
+        rule_id: InternedString::from_string(rule_id),
     })
 }
 
