@@ -1,5 +1,4 @@
 use crate::evaluation::evaluator_result::EvaluatorResult;
-use crate::spec_store::SpecStoreData;
 use crate::SpecsSource;
 use serde::{Deserialize, Serialize};
 
@@ -11,26 +10,48 @@ pub struct EvaluationDetails {
 }
 
 impl EvaluationDetails {
-    pub fn unrecognized(spec_store_data: &SpecStoreData) -> Self {
-        Self::create_from_data(spec_store_data, "Unrecognized", &EvaluatorResult::default())
+    pub fn unrecognized(source: &SpecsSource, lcut: u64, received_at: Option<u64>) -> Self {
+        Self::create_from_data(
+            source,
+            lcut,
+            received_at,
+            "Unrecognized",
+            &EvaluatorResult::default(),
+        )
     }
 
-    pub fn recognized_without_eval_result(spec_store_data: &SpecStoreData) -> Self {
-        Self::create_from_data(spec_store_data, "Recognized", &EvaluatorResult::default())
+    pub fn recognized_without_eval_result(
+        source: &SpecsSource,
+        lcut: u64,
+        received_at: Option<u64>,
+    ) -> Self {
+        Self::create_from_data(
+            source,
+            lcut,
+            received_at,
+            "Recognized",
+            &EvaluatorResult::default(),
+        )
     }
 
-    pub fn recognized(spec_store_data: &SpecStoreData, eval_result: &EvaluatorResult) -> Self {
-        Self::create_from_data(spec_store_data, "Recognized", eval_result)
+    pub fn recognized(
+        source: &SpecsSource,
+        lcut: u64,
+        received_at: Option<u64>,
+        eval_result: &EvaluatorResult,
+    ) -> Self {
+        Self::create_from_data(source, lcut, received_at, "Recognized", eval_result)
     }
 
     pub fn recognized_but_overridden(
-        spec_store_data: &SpecStoreData,
+        lcut: u64,
+        received_at: Option<u64>,
         override_reason: &str,
     ) -> Self {
         Self {
             reason: format!("{override_reason}:Recognized"),
-            lcut: Some(spec_store_data.values.time),
-            received_at: spec_store_data.time_received_at,
+            lcut: Some(lcut),
+            received_at,
         }
     }
 
@@ -53,13 +74,15 @@ impl EvaluationDetails {
     }
 
     fn create_from_data(
-        data: &SpecStoreData,
+        source: &SpecsSource,
+        lcut: u64,
+        received_at: Option<u64>,
         sub_reason: &str,
         eval_result: &EvaluatorResult,
     ) -> Self {
-        if data.source == SpecsSource::Uninitialized || data.source == SpecsSource::NoValues {
+        if *source == SpecsSource::Uninitialized || *source == SpecsSource::NoValues {
             return Self {
-                reason: data.source.to_string(),
+                reason: source.to_string(),
                 lcut: None,
                 received_at: None,
             };
@@ -67,16 +90,16 @@ impl EvaluationDetails {
 
         if eval_result.unsupported {
             return Self {
-                reason: format!("{}:Unsupported", data.source),
-                lcut: Some(data.values.time),
-                received_at: data.time_received_at,
+                reason: format!("{source}:Unsupported"),
+                lcut: Some(lcut),
+                received_at,
             };
         }
 
         Self {
-            reason: format!("{}:{}", data.source, sub_reason),
-            lcut: Some(data.values.time),
-            received_at: data.time_received_at,
+            reason: format!("{source}:{sub_reason}"),
+            lcut: Some(lcut),
+            received_at,
         }
     }
 }
