@@ -1,21 +1,71 @@
 use chrono::{DateTime, NaiveDateTime};
 use regex::Regex;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
-use serde_json::{Value as JsonValue, Value};
-use std::collections::HashMap;
+use serde_json::{value::RawValue, Value as JsonValue, Value};
+use std::{borrow::Cow, collections::HashMap, sync::Arc};
 
-use crate::{unwrap_or_return, DynamicValue};
+use crate::{
+    impl_interned_value, interned_string::InternedString, interned_value_store::FromRawValue,
+    log_e, unwrap_or_return, DynamicValue,
+};
 
 use super::dynamic_string::DynamicString;
 
-#[macro_export]
-macro_rules! test_only_make_eval_value {
-    ($x:expr) => {
-        $crate::evaluation::evaluator_value::EvaluatorValue::from(serde_json::json!($x))
+lazy_static::lazy_static! {
+    pub(crate) static ref EMPTY_EVALUATOR_VALUE: EvaluatorValue = EvaluatorValue {
+        hash: 0,
+        inner: Arc::new(MemoizedEvaluatorValue::new(EvaluatorValueType::Null)),
     };
 }
 
-#[derive(Debug, PartialEq)]
+const TAG: &str = "EvaluatorValue";
+
+#[derive(Clone, Debug)]
+pub struct EvaluatorValue {
+    pub hash: u64,
+    pub inner: Arc<MemoizedEvaluatorValue>,
+}
+
+impl_interned_value!(EvaluatorValue, MemoizedEvaluatorValue);
+
+impl EvaluatorValue {
+    pub fn empty() -> &'static Self {
+        &EMPTY_EVALUATOR_VALUE
+    }
+
+    pub fn compile_regex(&mut self) {
+        let mut_inner = Arc::make_mut(&mut self.inner);
+        mut_inner.compile_regex();
+    }
+}
+
+impl<'de> Deserialize<'de> for EvaluatorValue {
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        let raw_value_ref: Box<RawValue> = Deserialize::deserialize(deserializer)?;
+        let (hash, value) = EvaluatorValue::get_or_create_memoized(Cow::Owned(raw_value_ref));
+        Ok(EvaluatorValue { hash, inner: value })
+    }
+}
+
+impl Serialize for EvaluatorValue {
+    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        self.inner.serialize(serializer)
+    }
+}
+
+impl PartialEq for EvaluatorValue {
+    fn eq(&self, other: &Self) -> bool {
+        self.inner == other.inner
+    }
+}
+
+#[derive(Debug, PartialEq, Clone)]
 pub enum EvaluatorValueType {
     Null,
 
@@ -26,8 +76,8 @@ pub enum EvaluatorValueType {
     Object,
 }
 
-#[derive(Debug)]
-pub struct EvaluatorValue {
+#[derive(Debug, Clone)]
+pub struct MemoizedEvaluatorValue {
     pub value_type: EvaluatorValueType,
     pub bool_value: Option<bool>,
     pub float_value: Option<f64>,
@@ -35,11 +85,27 @@ pub struct EvaluatorValue {
     pub regex_value: Option<Regex>,
     pub timestamp_value: Option<i64>,
     // { lower_case_str: (index, str) } -- Keyed by lowercase string so we can lookup with O(1)
-    pub array_value: Option<HashMap<String, (usize, String)>>,
-    pub object_value: Option<HashMap<String, DynamicString>>,
+    pub array_value: Option<HashMap<InternedString, (usize, InternedString)>>,
+    pub object_value: Option<HashMap<InternedString, DynamicString>>,
 }
 
-impl EvaluatorValue {
+impl FromRawValue for MemoizedEvaluatorValue {
+    fn from_raw_value(raw_value: Cow<'_, RawValue>) -> Self {
+        match serde_json::from_str(raw_value.get()) {
+            Ok(value) => value,
+            Err(e) => {
+                log_e!(
+                    TAG,
+                    "Failed to convert raw value to MemoizedEvaluatorValue: {}",
+                    e
+                );
+                Self::null()
+            }
+        }
+    }
+}
+
+impl MemoizedEvaluatorValue {
     pub fn new(value_type: EvaluatorValueType) -> Self {
         Self {
             value_type,
@@ -114,7 +180,7 @@ impl EvaluatorValue {
                 }
 
                 for (k, v) in self_obj {
-                    let other_dyn_val = unwrap_or_return!(other_obj.get(k), false);
+                    let other_dyn_val = unwrap_or_return!(other_obj.get(k.as_str()), false);
                     let other_str_val = unwrap_or_return!(&other_dyn_val.string_value, false);
                     if other_str_val.value != v.value {
                         return false;
@@ -129,37 +195,37 @@ impl EvaluatorValue {
 
 // Used during evaluation:
 // - ua_parser
-impl From<String> for EvaluatorValue {
+impl From<String> for MemoizedEvaluatorValue {
     fn from(value: String) -> Self {
-        EvaluatorValue {
+        MemoizedEvaluatorValue {
             timestamp_value: try_parse_timestamp(&value),
             float_value: value.parse::<f64>().ok(),
             string_value: Some(DynamicString::from(value)),
-            ..EvaluatorValue::new(EvaluatorValueType::String)
+            ..MemoizedEvaluatorValue::new(EvaluatorValueType::String)
         }
     }
 }
 
 // Used during Deserialization
-impl From<JsonValue> for EvaluatorValue {
+impl From<JsonValue> for MemoizedEvaluatorValue {
     fn from(value: JsonValue) -> Self {
         match value {
-            JsonValue::Null => EvaluatorValue::new(EvaluatorValueType::Null),
+            JsonValue::Null => MemoizedEvaluatorValue::new(EvaluatorValueType::Null),
 
-            JsonValue::Bool(b) => EvaluatorValue {
+            JsonValue::Bool(b) => MemoizedEvaluatorValue {
                 bool_value: Some(b),
-                ..EvaluatorValue::new(EvaluatorValueType::Bool)
+                ..MemoizedEvaluatorValue::new(EvaluatorValueType::Bool)
             },
 
-            JsonValue::Number(n) => EvaluatorValue {
+            JsonValue::Number(n) => MemoizedEvaluatorValue {
                 float_value: n.as_f64(),
-                ..EvaluatorValue::new(EvaluatorValueType::Number)
+                ..MemoizedEvaluatorValue::new(EvaluatorValueType::Number)
             },
 
-            JsonValue::String(s) => EvaluatorValue::from(s),
+            JsonValue::String(s) => MemoizedEvaluatorValue::from(s),
 
             JsonValue::Array(arr) => {
-                let keyed_array: HashMap<String, (usize, String)> = arr
+                let keyed_array: HashMap<InternedString, (usize, InternedString)> = arr
                     .into_iter()
                     .enumerate()
                     .map(|(idx, val)| {
@@ -168,29 +234,33 @@ impl From<JsonValue> for EvaluatorValue {
                             None => val.to_string(),  // Value was not a String, but can be made one
                         };
 
-                        (str_value.to_lowercase(), (idx, str_value))
+                        let interned_lowercased_str =
+                            InternedString::from_string(str_value.to_lowercase());
+                        let interned_str = InternedString::from_string(str_value);
+
+                        (interned_lowercased_str, (idx, interned_str))
                     })
                     .collect();
 
-                EvaluatorValue {
+                MemoizedEvaluatorValue {
                     array_value: Some(keyed_array),
-                    ..EvaluatorValue::new(EvaluatorValueType::Array)
+                    ..MemoizedEvaluatorValue::new(EvaluatorValueType::Array)
                 }
             }
 
-            JsonValue::Object(obj) => EvaluatorValue {
+            JsonValue::Object(obj) => MemoizedEvaluatorValue {
                 object_value: Some(
                     obj.into_iter()
-                        .map(|(k, v)| (k, DynamicString::from(v)))
+                        .map(|(k, v)| (InternedString::from_string(k), DynamicString::from(v)))
                         .collect(),
                 ),
-                ..EvaluatorValue::new(EvaluatorValueType::Object)
+                ..MemoizedEvaluatorValue::new(EvaluatorValueType::Object)
             },
         }
     }
 }
 
-impl Serialize for EvaluatorValue {
+impl Serialize for MemoizedEvaluatorValue {
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
         S: Serializer,
@@ -209,7 +279,7 @@ impl Serialize for EvaluatorValue {
                 let mut result = vec![String::new(); array_map.len()];
 
                 for (idx, val) in array_map.values() {
-                    result[*idx] = val.clone();
+                    result[*idx] = val.unperformant_to_string();
                 }
 
                 result.serialize(serializer)
@@ -219,17 +289,17 @@ impl Serialize for EvaluatorValue {
     }
 }
 
-impl<'de> Deserialize<'de> for EvaluatorValue {
+impl<'de> Deserialize<'de> for MemoizedEvaluatorValue {
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
         D: Deserializer<'de>,
     {
         let json_value = JsonValue::deserialize(deserializer)?;
-        Ok(EvaluatorValue::from(json_value))
+        Ok(MemoizedEvaluatorValue::from(json_value))
     }
 }
 
-impl PartialEq for EvaluatorValue {
+impl PartialEq for MemoizedEvaluatorValue {
     fn eq(&self, other: &Self) -> bool {
         self.value_type == other.value_type
             && self.bool_value == other.bool_value
@@ -255,3 +325,10 @@ fn try_parse_timestamp(s: &str) -> Option<i64> {
 
     None
 }
+
+#[macro_export]
+macro_rules! test_only_make_eval_value {
+    ($x:expr) => {
+        $crate::evaluation::evaluator_value::MemoizedEvaluatorValue::from(serde_json::json!($x))
+    };
+}
