@@ -1,8 +1,8 @@
+pub mod gcir_formatter;
 pub mod gcir_options;
 
 pub(crate) mod dynamic_configs_processor;
 pub(crate) mod feature_gates_processor;
-pub(crate) mod gcir_formatter;
 pub(crate) mod gcir_process_iter;
 pub(crate) mod layer_configs_processor;
 pub(crate) mod param_stores_processor;
