@@ -2,7 +2,7 @@ pub use ahash::*;
 pub use djb2::*;
 pub use hash_util::*;
 
-mod ahash;
+pub mod ahash;
 mod djb2;
 mod hash_util;
 mod memo_sha_256;
